@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
                         KAboutLicense::LGPL,
                         i18n("© 2003-2005, Ralf Hoelzer"),
                         QString(),
-                        QStringLiteral("http://utils.kde.org/projects/sweeper"));
+                        QStringLiteral("https://utils.kde.org/projects/sweeper"));
 
    aboutData.addAuthor(i18n("Ralf Hoelzer"), i18n("Original author"), QStringLiteral("ralf@well.com"));
    aboutData.addAuthor(i18n("Brian S. Stephan"), i18n("Maintainer"), QStringLiteral("bssteph@irtonline.org"));
